# Acc Lib

Accelerator physics library containing plotting tools and other useful methods to handle data from X-suite tracking and other beam dynamics software, in constant evolution along with my PhD projects.

Installation can be easily done via: 
```pip install acc_lib```

The class `plot_tools` contains several plotting methods to illustrate the turn-by-turn data generated by X-suite trackers, including centroid evolution, phase space distributions, Twiss parameters, simple FFT and tune footprint. 

The class `particles` allows to display particle properties.

The class `madx_tools` contains methods to print errors from a crashed MAD-X process, print the elements neatly, plot the beam envelope, get the realistic apertures for both starting and end points of each element, and to plot the aperture together with the beam envelope.
